package javax.sound.midi;

import java.util.List;

public interface MidiDevice extends AutoCloseable
{
    public abstract MidiDevice.Info getDeviceInfo();
    
    public abstract void open() throws MidiUnavailableException;
    
    public abstract void close();
    
    public abstract boolean isOpen();
    
    public abstract long getMicrosecondPosition();
    
    public abstract int getMaxReceivers();
    
    public abstract int getMaxTransmitters();
    
    public abstract Receiver getReceiver() throws MidiUnavailableException;
    
    public abstract List<Receiver> getReceivers();
    
    public abstract Transmitter getTransmitter() throws MidiUnavailableException;
    
    public abstract List<Transmitter> getTransmitters();
    
    public static class Info
    {
        private String name;
        private String vendor;
        private String description;
        private String version;
        
        protected Info(String name, String vendor, String description, String version) {
            this.name = name;
            this.vendor = vendor;
            this.description = description;
            this.version = version;
        }
        
        @Override
        public final boolean equals(Object obj) {
            return super.equals(obj);
        }
        
        @Override
        public final int hashCode() {
            return super.hashCode();
        }
        
        public final String getName() {
            return this.name;
        }
        
        public final String getVendor() {
            return this.vendor;
        }
        
        public final String getDescription() {
            return this.description;
        }
        
        public final String getVersion() {
            return this.version;
        }
        
        @Override
        public final String toString() {
            return this.name;
        }
    }
}
